@@ -28,7 +28,7 @@
 //!
 //! However, sometimes you may want more control on the ticks, or want to use a type
 //! other than [`i128`]/[`f64`]/[`UnixTime`](num::timestamp::UnixTime). One way would be to write your own implementation of [`TickGenerator`].
-//! Alternatively you can use the [`Bound::steps`] function that just takes an iterator of ticks.
+//! Alternatively you can use the [`steps`] function that just takes an iterator of ticks.
 //! This puts more responsibility on the user to pass a decent number of ticks. This should only really be used when the user
 //! knows up front the min and max values of that axis. This is typically the case for
 //! at least one of the axis, typically the x axis. [See marathon example](https://github.com/tiby312/poloto/blob/master/examples/marathon.rs)
@@ -66,7 +66,6 @@ pub mod simple_theme;
 pub mod prelude {
     pub use super::formatm;
     pub use super::plotnum::TickFormat;
-    pub use super::plotnum::TickGenerator;
     pub use super::plottable::crop::Croppable;
     pub use super::simple_theme::SimpleTheme;
 }
@@ -146,29 +145,31 @@ pub struct Bound<X> {
     pub dash_info: DashInfo,
 }
 
-impl<X: PlotNum> Bound<X> {
-    ///
-    /// Create the default tick generator associated with a PlotNum.
-    ///
-    pub fn default_ticks(&self) -> TickDist<<X::DefaultTickGenerator as TickGenerator>::Fmt>
-    where
-        X::DefaultTickGenerator: TickGenerator<Num = X> + Default,
-    {
-        X::DefaultTickGenerator::default().generate(*self)
-    }
+pub fn from_gen<T: TickGenerator>(bound: Bound<T::Num>, a: T) -> TickDist<T::Fmt> {
+    a.generate(bound)
 }
 
-impl<X: PlotNum> Bound<X> {
-    ///
-    /// Create a [`num::Steps`].
-    ///
-    pub fn steps<I: Iterator<Item = X>, F: FnMut(&mut dyn fmt::Write, &X) -> fmt::Result>(
-        &self,
-        steps: I,
-        func: F,
-    ) -> TickDist<num::StepFmt<X, F>> {
-        num::Steps::new(steps, func).generate(*self)
-    }
+pub fn default_gen<X: PlotNum>(
+    bound: Bound<X>,
+) -> TickDist<<X::DefaultTickGenerator as TickGenerator>::Fmt>
+where
+    X::DefaultTickGenerator: TickGenerator<Num = X> + Default,
+{
+    X::DefaultTickGenerator::default().generate(bound)
+}
+
+///
+/// Create a [`num::Steps`].
+///
+pub fn steps<
+    X: PlotNum,
+    I: Iterator<Item = X>,
+    F: FnMut(&mut dyn fmt::Write, &X) -> fmt::Result,
+>(
+    steps: I,
+    func: F,
+) -> num::Steps<X, I, F> {
+    num::Steps::new(steps, func)
 }
 
 ///
@@ -189,9 +190,9 @@ impl<'a, X: PlotNum, Y: PlotNum> DataResult<'a, X, Y> {
     }
 
     ///
-    /// Automatically create a tick distribution using the default 
+    /// Automatically create a tick distribution using the default
     /// tick generators tied to a [`PlotNum`].
-    /// 
+    ///
     pub fn plot(
         self,
         title: impl Display + 'a,
@@ -202,16 +203,16 @@ impl<'a, X: PlotNum, Y: PlotNum> DataResult<'a, X, Y> {
         X::DefaultTickGenerator: TickGenerator<Num = X> + Default,
         Y::DefaultTickGenerator: TickGenerator<Num = Y> + Default,
     {
-        let x = self.boundx.default_ticks();
-        let y = self.boundy.default_ticks();
+        let x = default_gen(self.boundx);
+        let y = default_gen(self.boundy);
         self.plot_with(title, xname, yname, x, y)
     }
 
     ///
-    /// 
+    ///
     /// Move to final stage in pipeline collecting the title/xname/yname.
     /// Unlike [`DataResult::plot`] User must supply own tick distribution.
-    /// 
+    ///
     pub fn plot_with(
         self,
         title: impl Display + 'a,
@@ -478,7 +479,7 @@ impl<'a, X: PlotNum, Y: PlotNum> Data<'a, X, Y> {
     }
 }
 
-/// 
+///
 /// Created by [`DataResult::plot`] or [`DataResult::plot_with`]
 ///
 pub struct Plotter<'a, X: PlotNum + 'a, Y: PlotNum + 'a> {
